@@ -68,6 +68,16 @@ def get_hosts(
         click.echo(txt)
 
 
+@hosts.command()
+@click.argument('path', required=True)
+def export_hosts(path: str):
+    """
+    Write hosts to a file.
+    """
+    client = Client()
+    client.export_hosts(path=path)
+
+
 @hosts.command()
 @click.option('--asset-ids')
 @click.option('--host-ids')
