@@ -1,5 +1,4 @@
 from dataclasses import dataclass
-from edgescan.data.types.object import Object
 
 IP = 'ip'
 CIDR = 'cidr'
@@ -7,8 +6,7 @@ BLOCK = 'block'
 
 
 @dataclass(frozen=True)
-class LocationSpecifier(Object):
-    id: int
+class LocationSpecifier:
     location: str
     location_type: str
 
@@ -20,6 +18,3 @@ class LocationSpecifier(Object):
 
     def is_cidr(self) -> bool:
         return self.location_type == CIDR
-
-    def __hash__(self):
-        return self.id
